guix-patches
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[bug#58621] [PATCH 3/3] import/utils: spdx-string->license: Support '+'


From: Philip McGrath
Subject: [bug#58621] [PATCH 3/3] import/utils: spdx-string->license: Support '+' operator.
Date: Wed, 19 Oct 2022 01:04:49 -0400

Previously, '+' was supported only via special cases for deprecated
GNU identifiers like 'GPL-N+'.  This commit adds support
for other uses of '+', such as 'AFL-2.0+' and 'LPPL-1.0+'.

Strictly speaking, '+' is an operator, not part of the SPDX license
identifier, but it is useful to handle it here.

* guix/import/utils.scm (spdx-string->license): Support '+' operator.
---
 guix/import/utils.scm | 24 +++++++++++++++---------
 1 file changed, 15 insertions(+), 9 deletions(-)

diff --git a/guix/import/utils.scm b/guix/import/utils.scm
index 9944b606f3..a32fa4857e 100644
--- a/guix/import/utils.scm
+++ b/guix/import/utils.scm
@@ -139,10 +139,11 @@ (define %spdx-license-identifiers
   ;; Please update guix/licenses.scm when modifying
   ;; this list to avoid mismatches.
   ;;
   ;; "GPL-N+" has been deprecated in favour of "GPL-N-or-later".
   ;; "GPL-N" has been deprecated in favour of "GPL-N-only"
   ;; or "GPL-N-or-later" as appropriate.  Likewise for LGPL
   ;; and AGPL.
   '(("AGPL-1.0"                   . license:agpl1)
     ("AGPL-1.0-only"              . license:agpl1)
     ("AGPL-3.0"                   . license:agpl3)
@@ -255,10 +256,11 @@ (define %spdx-license-identifiers
     ("Zlib"                       . license:zlib)))
 
 (define (spdx-string->license str)
-  "Convert STR, an SPDX license identifier, to a symbol like 'license:gpl3+
-giving the prefixed name of a license object exported from (guix licenses).
-Return #f if STR does not match any known SPDX license identifiers.  Per the
-SPDX specification, license identifiers are compared case-insensitively."
+  "Convert STR, an SPDX license identifier (possibly with a postfix +
+operator), to a symbol like 'license:gpl3+ giving the prefixed name of a
+license object exported from (guix licenses).  Return #f if STR does not match
+any known SPDX license identifiers.  Per the SPDX specification, license
+identifiers are compared case-insensitively."
   ;; 
https://spdx.github.io/spdx-spec/v2.3/SPDX-license-expressions/#d2-case-sensitivity
   ;; Operators AND, OR, and WITH are case-sensitive, but identifiers are
   ;; case-insensitive for matching, though the canonical case is used in URIs.
@@ -266,7 +268,11 @@ (define (spdx-string->license str)
     ((_ . license)
      license)
     (#f
-     #f)))
+     (and (string-suffix? "+" str)
+          ;; We try the form with the + to support deprecated identifiers for
+          ;; GNU licenses (see above).  Here, we handle other uses of +.
+          (spdx-string->license
+           (substring str 0 (- (string-length str) 1)))))))
 
 (define (license->symbol license)
   "Convert LICENSE object to a prefixed symbol representing the variable the
@@ -139,10 +139,11 @@ (define %spdx-license-identifiers
   ;; this list to avoid mismatches.
   ;;
-  ;; "GPL-N+" has been deprecated in favour of "GPL-N-or-later".
-  ;; "GPL-N" has been deprecated in favour of "GPL-N-only"
-  ;; or "GPL-N-or-later" as appropriate.  Likewise for LGPL
-  ;; and AGPL.
+  ;; "GPL-N+" has been deprecated in favour of "GPL-N-or-later".  "GPL-N" has
+  ;; been deprecated in favour of "GPL-N-only" or "GPL-N-or-later" as
+  ;; appropriate.  Likewise for LGPL and AGPL.  However, we list the
+  ;; deprecated forms here (with and without the "+" operator) to get better
+  ;; results from old license expressions.
   '(("AGPL-1.0"                   . license:agpl1)
     ("AGPL-1.0-only"              . license:agpl1)
-- 
2.38.0






reply via email to

[Prev in Thread] Current Thread [Next in Thread]